aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/gl/GrGLEffect.h
diff options
context:
space:
mode:
authorGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-25 21:42:05 +0000
committerGravatar bsalomon@google.com <bsalomon@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2012-10-25 21:42:05 +0000
commit46fba0d79335f17429bb71d87a04d93fb2ee992b (patch)
treeba0a11312408578eeea662a47f249a6248081e74 /src/gpu/gl/GrGLEffect.h
parent0e363109199198e21237fa4e8314094917e62640 (diff)
Rename StageKey and related stuff.
R=robertphillips@google.com Review URL: https://codereview.appspot.com/6785049 git-svn-id: http://skia.googlecode.com/svn/trunk@6130 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'src/gpu/gl/GrGLEffect.h')
-rw-r--r--src/gpu/gl/GrGLEffect.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/gpu/gl/GrGLEffect.h b/src/gpu/gl/GrGLEffect.h
index 404f275b30..132c3d78de 100644
--- a/src/gpu/gl/GrGLEffect.h
+++ b/src/gpu/gl/GrGLEffect.h
@@ -23,7 +23,7 @@ class GrGLTexture;
include/gpu/GrEffect.h. Objects of type GrGLEffect are responsible for emitting the
GLSL code that implements a GrEffect and for uploading uniforms at draw time. They also
must have a function:
- static inline StageKey GenKey(const GrEffect&, const GrGLCaps&)
+ static inline EffectKey GenKey(const GrEffect&, const GrGLCaps&)
that is used to implement a program cache. When two GrEffects produce the same key this means
that their GrGLEffects would emit the same GLSL code.
@@ -33,10 +33,10 @@ class GrGLTexture;
class GrGLEffect {
public:
- typedef GrEffect::StageKey StageKey;
+ typedef GrEffect::EffectKey EffectKey;
enum {
- // the number of bits in StageKey available to GenKey
- kProgramStageKeyBits = GrBackendEffectFactory::kProgramStageKeyBits,
+ // the number of bits in EffectKey available to GenKey
+ kEffectKeyBits = GrBackendEffectFactory::kEffectKeyBits,
};
typedef GrGLShaderBuilder::TextureSamplerArray TextureSamplerArray;
@@ -51,7 +51,7 @@ public:
@param builder Interface used to emit code in the shaders.
@param effect The effect that generated this program stage.
- @param key The key that was computed by StageKey() from the generating GrEffect.
+ @param key The key that was computed by EffectKey() from the generating GrEffect.
@param vertexCoords A vec2 of texture coordinates in the VS, which may be altered. This will
be removed soon and stages will be responsible for computing their own
coords.
@@ -68,7 +68,7 @@ public:
*/
virtual void emitCode(GrGLShaderBuilder* builder,
const GrEffect& effect,
- StageKey key,
+ EffectKey key,
const char* vertexCoords,
const char* outputColor,
const char* inputColor,
@@ -81,7 +81,7 @@ public:
const char* name() const { return fFactory.name(); }
- static StageKey GenTextureKey(const GrEffect&, const GrGLCaps&);
+ static EffectKey GenTextureKey(const GrEffect&, const GrGLCaps&);
protected:
@@ -107,7 +107,7 @@ public:
virtual void emitCode(GrGLShaderBuilder* builder,
const GrEffect&,
- StageKey,
+ EffectKey,
const char* vertexCoords,
const char* outputColor,
const char* inputColor,